@@ -56,6 +56,7 @@ long cm_BufWrite(void *vfidp, osi_hyper_t *offsetp, long length, long flags,
     AFSVolSync volSync;
     AFSFid tfid;
     struct rx_call *callp;
+    struct rx_connection *rxconnp;
     osi_queueData_t *qdp;
     cm_buf_t *bufp;
     long wbytes;
@@ -129,11 +130,11 @@ long cm_BufWrite(void *vfidp, osi_hyper_t *offsetp, long length, long flags,
         if (code) 
             continue;
 		
-        lock_ObtainMutex(&connp->mx);
-        callp = rx_NewCall(connp->callp);
-        lock_ReleaseMutex(&connp->mx);
+        rxconnp = cm_GetRxConn(connp);
+        callp = rx_NewCall(rxconnp);
+        rx_PutConnection(rxconnp);
 
-        osi_Log3(afsd_logp, "CALL StoreData vp %x, off 0x%x, size 0x%x",
+        osi_Log3(afsd_logp, "CALL StoreData scp 0x%x, off 0x%x, size 0x%x",
                  (long) scp, biod.offset.LowPart, nbytes);
 
         code = StartRXAFS_StoreData(callp, &tfid, &inStatus,
@@ -175,11 +176,15 @@ long cm_BufWrite(void *vfidp, osi_hyper_t *offsetp, long length, long flags,
                 osi_Log1(afsd_logp, "EndRXAFS_StoreData failed (%lX)",code);
         }
         code = rx_EndCall(callp, code);
-        osi_Log0(afsd_logp, "CALL StoreData DONE");
                 
     } while (cm_Analyze(connp, userp, reqp, &scp->fid, &volSync, NULL, NULL, code));
     code = cm_MapRPCError(code, reqp);
         
+    if (code)
+        osi_Log1(afsd_logp, "CALL StoreData FAILURE, code 0x%x", code);
+    else
+        osi_Log0(afsd_logp, "CALL StoreData SUCCESS");
+
     /* now, clean up our state */
     lock_ObtainMutex(&scp->mx);
 
@@ -235,6 +240,7 @@ long cm_StoreMini(cm_scache_t *scp, cm_user_t *userp, cm_req_t *reqp)
     long truncPos;
     cm_conn_t *connp;
     struct rx_call *callp;
+    struct rx_connection *rxconnp;
 
     /* Serialize StoreData RPC's; for rationale see cm_scache.c */
     (void) cm_SyncOp(scp, NULL, userp, reqp, 0,
@@ -262,9 +268,9 @@ long cm_StoreMini(cm_scache_t *scp, cm_user_t *userp, cm_req_t *reqp)
         if (code) 
             continue;
 		
-        lock_ObtainMutex(&connp->mx);
-        callp = rx_NewCall(connp->callp);
-        lock_ReleaseMutex(&connp->mx);
+        rxconnp = cm_GetRxConn(connp);
+        callp = rx_NewCall(rxconnp);
+        rx_PutConnection(rxconnp);
 
         code = StartRXAFS_StoreData(callp, &tfid, &inStatus,
                                     0, 0, truncPos);
@@ -721,7 +727,9 @@ long cm_SetupStoreBIOD(cm_scache_t *scp, osi_hyper_t *inOffsetp, long inSize,
             break;
 
         /* try to lock it, and quit if we can't (simplifies locking) */
+        lock_ReleaseMutex(&scp->mx);
         code = lock_TryMutex(&bufp->mx);
+        lock_ObtainMutex(&scp->mx);
         if (code == 0) {
             buf_Release(bufp);
             break;
@@ -775,7 +783,9 @@ long cm_SetupStoreBIOD(cm_scache_t *scp, osi_hyper_t *inOffsetp, long inSize,
             break;
 
         /* try to lock it, and quit if we can't (simplifies locking) */
+        lock_ReleaseMutex(&scp->mx);
         code = lock_TryMutex(&bufp->mx);
+        lock_ObtainMutex(&scp->mx);
         if (code == 0) {
             buf_Release(bufp);
             break;
@@ -884,27 +894,27 @@ long cm_SetupFetchBIOD(cm_scache_t *scp, osi_hyper_t *offsetp,
      * sequence at a time.
      */
 
+    // lock_ObtainMutex(&cm_bufGetMutex);
     /* first hold all buffers, since we can't hold any locks in buf_Get */
     while (1) {
         /* stop at chunk boundary */
-        if (collected >= cm_chunkSize) break;
+        if (collected >= cm_chunkSize) 
+            break;
                 
         /* see if the next page would be past EOF */
-        if (LargeIntegerGreaterThanOrEqualTo(pageBase, fileSize)) break;
-
-        lock_ObtainMutex(&cm_bufGetMutex);
+        if (LargeIntegerGreaterThanOrEqualTo(pageBase, fileSize)) 
+            break;
 
         code = buf_Get(scp, &pageBase, &tbp);
         if (code) {
             lock_ReleaseMutex(&cm_bufGetMutex);
             lock_ObtainMutex(&scp->mx);
+            cm_SyncOpDone(scp, NULL, CM_SCACHESYNC_NEEDCALLBACK | CM_SCACHESYNC_GETSTATUS);
             return code;
         }
                 
         buf_Release(tbp);
 
-        lock_ReleaseMutex(&cm_bufGetMutex);
-
         toffset.HighPart = 0;
         toffset.LowPart = cm_data.buf_blockSize;
         pageBase = LargeIntegerAdd(toffset, pageBase);
@@ -914,6 +924,8 @@ long cm_SetupFetchBIOD(cm_scache_t *scp, osi_hyper_t *offsetp,
     /* reserve a chunk's worth of buffers if possible */
     reserving = buf_TryReserveBuffers(cm_chunkSize / cm_data.buf_blockSize);
 
+    // lock_ReleaseMutex(&cm_bufGetMutex);
+
     pageBase = *offsetp;
     collected = pageBase.LowPart & (cm_chunkSize - 1);
 
@@ -1117,6 +1129,7 @@ long cm_GetBuffer(cm_scache_t *scp, cm_buf_t *bufp, int *cpffp, cm_user_t *up,
     osi_queueData_t *qdp;		/* q element we're scanning */
     AFSFid tfid;
     struct rx_call *callp;
+    struct rx_connection *rxconnp;
     cm_bulkIO_t biod;		/* bulk IO descriptor */
     cm_conn_t *connp;
     int getroot;
@@ -1247,10 +1260,10 @@ long cm_GetBuffer(cm_scache_t *scp, cm_buf_t *bufp, int *cpffp, cm_user_t *up,
         code = cm_Conn(&scp->fid, up, reqp, &connp);
         if (code) 
             continue;
-		
-        lock_ObtainMutex(&connp->mx);
-        callp = rx_NewCall(connp->callp);
-        lock_ReleaseMutex(&connp->mx);
+	
+        rxconnp = cm_GetRxConn(connp);
+        callp = rx_NewCall(rxconnp);
+        rx_PutConnection(rxconnp);
 
         osi_Log3(afsd_logp, "CALL FetchData vp %x, off 0x%x, size 0x%x",
                   (long) scp, biod.offset.LowPart, biod.length);
@@ -1369,6 +1382,9 @@ long cm_GetBuffer(cm_scache_t *scp, cm_buf_t *bufp, int *cpffp, cm_user_t *up,
     code = cm_MapRPCError(code, reqp);
 
     lock_ObtainMutex(&scp->mx);
+    
+    cm_SyncOpDone(scp, NULL, CM_SCACHESYNC_FETCHSTATUS);
+
     /* we know that no one else has changed the buffer, since we still have
      * the fetching flag on the buffers, and we have the scp locked again.
      * Copy in the version # into the buffer if we got code 0 back from the
