@@ -11,8 +11,11 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_file.c,v 1.18 2003/08/15 23:50:27 kolya Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_file.c,v 1.19.2.7 2005/04/24 20:12:22 shadow Exp $");
 
+#ifdef AFS_LINUX24_ENV
+#include "h/module.h" /* early to avoid printf->printk mapping */
+#endif
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs/afs_stats.h"	/* afs statistics */
@@ -23,16 +26,105 @@ int afs_osicred_initialized = 0;
 struct AFS_UCRED afs_osi_cred;
 afs_lock_t afs_xosi;		/* lock is for tvattr */
 extern struct osi_dev cacheDev;
+#if defined(AFS_LINUX24_ENV)
+extern struct vfsmount *afs_cacheMnt;
+#endif
 extern struct super_block *afs_cacheSBp;
 
+/*#if defined(AFS_LINUX26_ENV) && (defined(CONFIG_EXPORTFS) || defined(CONFIG_EXPORTFS_MODULE))
+#define HAS_UFSOPEN
+extern struct export_operations export_op_default;
+
+#define CALL(ops,fun) ((ops->fun)?(ops->fun):export_op_default.fun)
+
+XXX something based on encode_fh / find_exported_dentry 
+This would require us to store an inode -> fh mapping (acquired by
+afs_InitCacheFile or lookupname), but probably solves the resiserfs issue.
+#elif... */
+
+#if defined(AFS_LINUX24_ENV) && !defined(HAS_UFSOPEN)
+#define HAS_UFSOPEN
+void *
+osi_UFSOpen(afs_int32 ainode)
+{
+    register struct osi_file *afile = NULL;
+    extern int cacheDiskType;
+    struct inode *tip = NULL;
+#ifndef AFS_LINUX26_ENV
+    afs_int32 code = 0;
+    struct list_head *lp = NULL;
+    struct dentry *tdp = NULL;
+#endif
+    struct dentry *dp = NULL;
+    struct file *filp = NULL;
+    AFS_STATCNT(osi_UFSOpen);
+    if (cacheDiskType != AFS_FCACHE_TYPE_UFS) {
+	osi_Panic("UFSOpen called for non-UFS cache\n");
+    }
+    if (!afs_osicred_initialized) {
+	/* valid for alpha_osf, SunOS, Ultrix */
+	memset((char *)&afs_osi_cred, 0, sizeof(struct AFS_UCRED));
+	crhold(&afs_osi_cred);	/* don't let it evaporate, since it is static */
+	afs_osicred_initialized = 1;
+    }
+    afile = (struct osi_file *)osi_AllocLargeSpace(sizeof(struct osi_file));
+    AFS_GUNLOCK();
+    if (!afile) {
+	osi_Panic("osi_UFSOpen: Failed to allocate %d bytes for osi_file.\n",
+		  sizeof(struct osi_file));
+    }
+    memset(afile, 0, sizeof(struct osi_file));
+    tip = iget(afs_cacheSBp, (u_long) ainode);
+    if (!tip)
+	osi_Panic("Can't get inode %d\n", ainode);
+    tip->i_flags |= MS_NOATIME;	/* Disable updating access times. */
+
+#ifdef AFS_LINUX26_ENV
+    dp = d_alloc_anon(tip);
+#else
+    spin_lock(&dcache_lock);
+    for (lp = tip->i_dentry.next;  lp != &tip->i_dentry; lp = lp->next) {
+        tdp = list_entry(lp, struct dentry, d_alias);
+        if ( !(tdp->d_flags & DCACHE_NFSD_DISCONNECTED)) {
+             dget_locked(tdp);
+             dp=tdp;
+             break;
+        }
+    }
+    if (tdp && !dp) {
+             dget_locked(tdp);
+             dp=tdp;
+    }
+    tdp = NULL;
+    spin_unlock(&dcache_lock);
+    if (!dp)
+           dp = d_alloc_root(tip);
+    iput(tip);
+#endif
+    if (!dp) 
+           osi_Panic("Can't get dentry for inode %d\n", ainode);          
+
+    filp = dentry_open(dp, mntget(afs_cacheMnt), O_RDWR);
+
+    if (IS_ERR(filp))
+	osi_Panic("Can't open inode %d\n", ainode);
+    afile->filp = filp;
+    afile->size = FILE_INODE(filp)->i_size;
+    AFS_GLOCK();
+    afile->offset = 0;
+    afile->proc = (int (*)())0;
+    afile->inum = ainode;	/* for hint validity checking */
+    return (void *)afile;
+}
+#endif
+
+#if !defined(HAS_UFSOPEN)
 void *
 osi_UFSOpen(afs_int32 ainode)
 {
-    struct inode *ip;
     register struct osi_file *afile = NULL;
     extern int cacheDiskType;
     afs_int32 code = 0;
-    int dummy;
     struct inode *tip = NULL;
     struct file *filp = NULL;
     AFS_STATCNT(osi_UFSOpen);
@@ -60,7 +152,11 @@ osi_UFSOpen(afs_int32 ainode)
     FILE_INODE(filp) = tip;
     tip->i_flags |= MS_NOATIME;	/* Disable updating access times. */
     filp->f_flags = O_RDWR;
+#if defined(AFS_LINUX26_ENV)
+    filp->f_mapping = tip->i_mapping;
+#endif
 #if defined(AFS_LINUX24_ENV)
+    filp->f_mode = FMODE_READ|FMODE_WRITE;
     filp->f_op = fops_get(tip->i_fop);
 #else
     filp->f_op = tip->i_op->default_file_ops;
@@ -76,6 +172,7 @@ osi_UFSOpen(afs_int32 ainode)
     afile->inum = ainode;	/* for hint validity checking */
     return (void *)afile;
 }
+#endif
 
 int
 afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
@@ -83,15 +180,35 @@ afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
     register afs_int32 code;
     AFS_STATCNT(osi_Stat);
     MObtainWriteLock(&afs_xosi, 320);
-    astat->size = FILE_INODE(&afile->file)->i_size;
-    astat->blksize = FILE_INODE(&afile->file)->i_blksize;
-    astat->mtime = FILE_INODE(&afile->file)->i_mtime;
-    astat->atime = FILE_INODE(&afile->file)->i_atime;
+    astat->size = OSIFILE_INODE(afile)->i_size;
+    astat->blksize = OSIFILE_INODE(afile)->i_blksize;
+#if defined(AFS_LINUX26_ENV)
+    astat->mtime = OSIFILE_INODE(afile)->i_mtime.tv_sec;
+    astat->atime = OSIFILE_INODE(afile)->i_atime.tv_sec;
+#else
+    astat->mtime = OSIFILE_INODE(afile)->i_mtime;
+    astat->atime = OSIFILE_INODE(afile)->i_atime;
+#endif
     code = 0;
     MReleaseWriteLock(&afs_xosi);
     return code;
 }
 
+#ifdef AFS_LINUX24_ENV
+int
+osi_UFSClose(register struct osi_file *afile)
+{
+    AFS_STATCNT(osi_Close);
+    if (afile) {
+	if (OSIFILE_INODE(afile)) {
+             filp_close(afile->filp, NULL);
+	}
+    }
+
+    osi_FreeLargeSpace(afile);
+    return 0;
+}
+#else
 int
 osi_UFSClose(register struct osi_file *afile)
 {
@@ -108,15 +225,15 @@ osi_UFSClose(register struct osi_file *afile)
     osi_FreeLargeSpace(afile);
     return 0;
 }
+#endif
 
 int
 osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
 {
-    struct AFS_UCRED *oldCred;
     register afs_int32 code;
     struct osi_stat tstat;
     struct iattr newattrs;
-    struct inode *inode = FILE_INODE(&afile->file);
+    struct inode *inode = OSIFILE_INODE(afile);
     AFS_STATCNT(osi_Truncate);
 
     /* This routine only shrinks files, and most systems
@@ -132,7 +249,7 @@ osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
     down_write(&inode->i_alloc_sem);
 #endif
     down(&inode->i_sem);
-    inode->i_size = newattrs.ia_size = asize;
+    newattrs.ia_size = asize;
     newattrs.ia_valid = ATTR_SIZE | ATTR_CTIME;
 #if defined(AFS_LINUX24_ENV)
     newattrs.ia_ctime = CURRENT_TIME;
@@ -150,6 +267,7 @@ osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
     if (!code)
 	truncate_inode_pages(&inode->i_data, asize);
 #else
+    inode->i_size = asize;
     if (inode->i_sb->s_op && inode->i_sb->s_op->notify_change) {
 	code = inode->i_sb->s_op->notify_change(&afile->dentry, &newattrs);
     }
@@ -175,16 +293,16 @@ int
 afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
 	     afs_int32 asize)
 {
-    struct AFS_UCRED *oldCred;
-    size_t resid;
-    register afs_int32 code;
-    register afs_int32 cnt1 = 0;
+    struct uio auio;
+    struct iovec iov;
+    afs_int32 code;
+
     AFS_STATCNT(osi_Read);
 
-    /**
-      * If the osi_file passed in is NULL, panic only if AFS is not shutting
-      * down. No point in crashing when we are already shutting down
-      */
+    /*
+     * If the osi_file passed in is NULL, panic only if AFS is not shutting
+     * down. No point in crashing when we are already shutting down
+     */
     if (!afile) {
 	if (!afs_shuttingdown)
 	    osi_Panic("osi_Read called with null param");
@@ -194,14 +312,15 @@ afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
 
     if (offset != -1)
 	afile->offset = offset;
+    setup_uio(&auio, &iov, aptr, afile->offset, asize, UIO_READ, AFS_UIOSYS);
     AFS_GUNLOCK();
-    code = osi_rdwr(UIO_READ, afile, (caddr_t) aptr, asize, &resid);
+    code = osi_rdwr(afile, &auio, UIO_READ);
     AFS_GLOCK();
     if (code == 0) {
-	code = asize - resid;
+	code = asize - auio.uio_resid;
 	afile->offset += code;
     } else {
-	afs_Trace2(afs_iclSetp, CM_TRACE_READFAILED, ICL_TYPE_INT32, resid,
+	afs_Trace2(afs_iclSetp, CM_TRACE_READFAILED, ICL_TYPE_INT32, auio.uio_resid,
 		   ICL_TYPE_INT32, code);
 	code = -1;
     }
@@ -213,23 +332,27 @@ int
 afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 	      afs_int32 asize)
 {
-    struct AFS_UCRED *oldCred;
-    size_t resid;
-    register afs_int32 code;
+    struct uio auio;
+    struct iovec iov;
+    afs_int32 code;
+
     AFS_STATCNT(osi_Write);
+
     if (!afile) {
 	if (!afs_shuttingdown)
 	    osi_Panic("afs_osi_Write called with null param");
 	else
 	    return EIO;
     }
+
     if (offset != -1)
 	afile->offset = offset;
+    setup_uio(&auio, &iov, aptr, afile->offset, asize, UIO_WRITE, AFS_UIOSYS);
     AFS_GUNLOCK();
-    code = osi_rdwr(UIO_WRITE, afile, (caddr_t) aptr, asize, &resid);
+    code = osi_rdwr(afile, &auio, UIO_WRITE);
     AFS_GLOCK();
     if (code == 0) {
-	code = asize - resid;
+	code = asize - auio.uio_resid;
 	afile->offset += code;
     } else {
 	if (code == ENOSPC)
@@ -237,9 +360,10 @@ afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 		("\n\n\n*** Cache partition is FULL - Decrease cachesize!!! ***\n\n");
 	code = -1;
     }
-    if (afile->proc) {
-	(*afile->proc) (afile, code);
-    }
+
+    if (afile->proc)
+	(*afile->proc)(afile, code);
+
     return code;
 }
 
